<?php
/**
 * Template Functions
 *
 * Utility functions.
 *
 * @package Once
 */

if ( ! function_exists( 'csco_doing_request' ) ) {
	/**
	 * Determines whether the current request is a WordPress REST or Ajax request.
	 */
	function csco_doing_request() {
		if ( defined( 'REST_REQUEST' ) && REST_REQUEST ) {
			return true;
		}
		if ( defined( 'DOING_AJAX' ) && DOING_AJAX ) {
			return true;
		}
	}
}

if ( ! function_exists( 'csco_style' ) ) {
	/**
	 * Processing path of style.
	 *
	 * @param string $path URL to the stylesheet.
	 */
	function csco_style( $path ) {
		// Check RTL.
		if ( is_rtl() ) {
			return $path;
		}

		// Check Dev.
		$dev = get_theme_file_path( 'style-dev.css' );

		if ( file_exists( $dev ) ) {
			return str_replace( '.css', '-dev.css', $path );
		}

		return $path;
	}
}

if ( ! function_exists( 'csco_get_locale' ) ) {
	/**
	 * Get locale in uniform format.
	 */
	function csco_get_locale() {

		$csco_locale = get_locale();

		if ( preg_match( '#^[a-z]{2}\-[A-Z]{2}$#', $csco_locale ) ) {
			$csco_locale = str_replace( '-', '_', $csco_locale );
		} elseif ( preg_match( '#^[a-z]{2}$#', $csco_locale ) ) {
			if ( function_exists( 'mb_strtoupper' ) ) {
				$csco_locale .= '_' . mb_strtoupper( $csco_locale, 'UTF-8' );
			} else {
				$csco_locale .= '_' . strtoupper( $csco_locale );
			}
		}

		if ( empty( $csco_locale ) ) {
			$csco_locale = 'en_US';
		}

		return apply_filters( 'csco_locale', $csco_locale );

	}
}

if ( ! function_exists( 'csco_get_theme_data' ) ) {
	/**
	 * Get data about the theme.
	 *
	 * @param mixed $name The name of param.
	 */
	function csco_get_theme_data( $name ) {
		$theme = wp_get_theme( get_template() );

		return $theme->get( $name );
	}
}

if ( ! function_exists( 'csco_rgba2hex' ) ) {
	/**
	 * Convert rgba to hex.
	 *
	 * @param mixed $color Color.
	 */
	function csco_rgba2hex( $color ) {
		if ( isset( $color[0] ) && '#' === $color[0] ) {
			return $color;
		}

		$rgba = array();

		if ( preg_match_all( '#\((([^()]+|(?R))*)\)#', $color, $matches ) ) {
			$rgba = explode( ',', implode( ' ', $matches[1] ) );
		} else {
			$rgba = explode( ',', $color );
		}

		$rr = dechex( $rgba['0'] );
		$gg = dechex( $rgba['1'] );
		$bb = dechex( $rgba['2'] );
		$aa = '';

		if ( array_key_exists( '3', $rgba ) ) {
			$aa = dechex( $rgba['3'] * 255 );
		}

		return strtoupper( "#$aa$rr$gg$bb" );
	}
}

if ( ! function_exists( 'csco_hex_is_light' ) ) {
	/**
	 * Determine whether a hex color is light.
	 *
	 * @param mixed $color Color.
	 * @return bool  True if a light color.
	 */
	function csco_hex_is_light( $color ) {
		$hex        = str_replace( '#', '', $color );
		$c_r        = hexdec( substr( $hex, 0, 2 ) );
		$c_g        = hexdec( substr( $hex, 2, 2 ) );
		$c_b        = hexdec( substr( $hex, 4, 2 ) );
		$brightness = ( ( $c_r * 299 ) + ( $c_g * 587 ) + ( $c_b * 114 ) ) / 1000;
		return $brightness > 190;
	}
}

if ( ! function_exists( 'csco_implode' ) ) {
	/**
	 * Join array elements with a string
	 *
	 * @param array  $pieces The array of strings to implode.
	 * @param string $glue   Defaults to an empty string.
	 */
	function csco_implode( $pieces, $glue = ', ' ) {
		if ( is_array( $pieces ) ) {
			return implode( $glue, $pieces );
		}
		if ( is_string( $pieces ) ) {
			return $pieces;
		}
	}
}

if ( ! function_exists( 'csco_light_or_dark' ) ) {
	/**
	 * Detect if we should use a light or dark color on a background color.
	 *
	 * @param mixed  $color Color.
	 * @param string $dark  Darkest reference.
	 *                      Defaults to '#000000'.
	 * @param string $light Lightest reference.
	 *                      Defaults to '#FFFFFF'.
	 * @return string
	 */
	function csco_light_or_dark( $color, $dark = '#000000', $light = '#FFFFFF' ) {
		return csco_hex_is_light( $color ) ? $dark : $light;
	}
}

if ( ! function_exists( 'csco_get_round_number' ) ) {
	/**
	 * Get rounded number.
	 *
	 * @param int $number    Input number.
	 * @param int $min_value Minimum value to round number.
	 * @param int $decimal   How may decimals shall be in the rounded number.
	 */
	function csco_get_round_number( $number, $min_value = 1000, $decimal = 1 ) {
		if ( $number < $min_value ) {
			return number_format_i18n( $number );
		}
		$alphabets = array(
			1000000000 => esc_html__( 'B', 'once' ),
			1000000    => esc_html__( 'M', 'once' ),
			1000       => esc_html__( 'K', 'once' ),
		);
		foreach ( $alphabets as $key => $value ) {
			if ( $number >= $key ) {
				return number_format_i18n( round( $number / $key, $decimal ), $decimal ) . $value;
			}
		}
	}
}

if ( ! function_exists( 'csco_the_round_number' ) ) {
	/**
	 * Echo rounded number.
	 *
	 * @param int $number    Input number.
	 * @param int $min_value Minimum value to round number.
	 * @param int $decimal   How may decimals shall be in the rounded number.
	 */
	function csco_the_round_number( $number, $min_value = 1000, $decimal = 1 ) {
		echo esc_html( csco_get_round_number( $number, $min_value, $decimal ) );
	}
}

if ( ! function_exists( 'csco_str_truncate' ) ) {
	/**
	 * Truncates string with specified length
	 *
	 * @param  string $string      Text string.
	 * @param  int    $length      Letters length.
	 * @param  string $etc         End truncate.
	 * @param  bool   $break_words Break words or not.
	 * @return string
	 */
	function csco_str_truncate( $string, $length = 80, $etc = '&hellip;', $break_words = false ) {
		if ( 0 === $length ) {
			return '';
		}

		if ( function_exists( 'mb_strlen' ) ) {

			// MultiBite string functions.
			if ( mb_strlen( $string ) > $length ) {
				$length -= min( $length, mb_strlen( $etc ) );
				if ( ! $break_words ) {
					$string = preg_replace( '/\s+?(\S+)?$/', '', mb_substr( $string, 0, $length + 1 ) );
				}

				return mb_substr( $string, 0, $length ) . $etc;
			}
		} else {

			// Default string functions.
			if ( strlen( $string ) > $length ) {
				$length -= min( $length, strlen( $etc ) );
				if ( ! $break_words ) {
					$string = preg_replace( '/\s+?(\S+)?$/', '', substr( $string, 0, $length + 1 ) );
				}

				return substr( $string, 0, $length ) . $etc;
			}
		}

		return $string;
	}
}

if ( ! function_exists( 'csco_svg_encode' ) ) {
	/**
	 * Encode svg symbols.
	 *
	 * @param string $string Text string.
	 */
	function csco_svg_encode( $string ) {

		$map = array(
			'<' => '%3C',
			'>' => '%3E',
			'#' => '%23',
		);

		foreach ( $map as $key => $value ) {
			$string = str_replace( $key, $value, $string );
		}

		return $string;
	}
}

if ( ! function_exists( 'csco_get_retina_image' ) ) {
	/**
	 * Get retina image.
	 *
	 * @param int    $attachment_id Image attachment ID.
	 * @param array  $attr          Attributes for the image markup. Default empty.
	 * @param string $type          The tag of type.
	 */
	function csco_get_retina_image( $attachment_id, $attr = array(), $type = 'img' ) {
		$attachment_url = wp_get_attachment_url( $attachment_id );

		// Retina image.
		$attached_file = get_attached_file( $attachment_id );

		if ( $attached_file ) {
			$uriinfo  = pathinfo( $attachment_url );
			$pathinfo = pathinfo( $attached_file );

			$retina_uri  = sprintf( '%s/%s@2x.%s', $uriinfo['dirname'], $uriinfo['filename'], $uriinfo['extension'] );
			$retina_file = sprintf( '%s/%s@2x.%s', $pathinfo['dirname'], $pathinfo['filename'], $pathinfo['extension'] );

			if ( file_exists( $retina_file ) ) {
				$attr['srcset'] = sprintf( '%s 1x, %s 2x', $attachment_url, $retina_uri );
			}
		}

		// Sizes.
		if ( 'amp-img' === $type ) {
			$data = wp_get_attachment_image_src( $attachment_id, 'full' );

			if ( isset( $data[1] ) ) {
				$attr['width'] = $data[1];
			}
			if ( isset( $data[2] ) ) {
				$attr['height'] = $data[2];
			}

			// Calc max height and set new width depending on proportion.
			if ( isset( $attr['width'] ) && isset( $attr['height'] ) ) {
				$max_height = get_theme_mod( 'header_nav_height', '80px' );

				$max_height = (int) str_replace( 'px', '', $max_height );

				if ( $max_height > 0 && $attr['height'] > $max_height ) {
					$attr['width'] = $attr['width'] / $attr['height'] * $max_height;

					$attr['height'] = $max_height;
				}
			}
		}

		// Attr.
		$output = '';

		foreach ( $attr as $name => $value ) {
			$output .= sprintf( ' %s="%s" ', esc_attr( $name ), esc_attr( $value ) );
		}

		// Image output.
		printf( '<%1$s src="%2$s" %3$s>', esc_attr( $type ), esc_url( $attachment_url ), $output ); // XSS ok.
	}
}

if ( ! function_exists( 'csco_offcanvas_exists' ) ) {
	/**
	 * Check if offcanvas exists.
	 */
	function csco_offcanvas_exists() {
		$locations = get_nav_menu_locations();

		if ( isset( $locations['primary'] ) || isset( $locations['mobile'] ) || is_active_sidebar( 'sidebar-offcanvas' ) ) {
			return true;
		}
	}
}

if ( ! function_exists( 'csco_site_content_class' ) ) {
	/**
	 * Display the classes for the site-content element.
	 *
	 * @param array $class Classes to add to the class list.
	 */
	function csco_site_content_class( $class = array() ) {
		$class[] = 'site-content';

		$class = apply_filters( 'csco_site_content_class', $class );

		// Separates classes with a single space, collates classes.
		echo sprintf( 'class="%s"', esc_attr( join( ' ', $class ) ) );
	}
}

if ( ! function_exists( 'csco_has_post_meta' ) ) {
	/**
	 * Check if the meta has display.
	 *
	 * @param string $meta     The name of meta.
	 * @param string $location The location of meta.
	 */
	function csco_has_post_meta( $meta, $location = 'post_meta' ) {
		return in_array( $meta, (array) get_theme_mod( $location, array( $meta ) ), true );
	}
}

if ( ! function_exists( 'csco_coauthors_enabled' ) ) {
	/**
	 * Is it possible to check whether it is possible to output CoAuthors.
	 */
	function csco_coauthors_enabled() {
		if ( class_exists( 'Powerkit' ) && class_exists( 'CoAuthors_Plus' ) ) {
			return true;
		}
	}
}

if ( ! function_exists( 'csco_get_coauthors' ) ) {
	/**
	 * Return CoAuthors.
	 */
	function csco_get_coauthors() {
		$authors = array();

		if ( csco_coauthors_enabled() ) {
			$authors = get_coauthors();

			if ( apply_filters( 'csco_coauthors_sort_abc', true ) && $authors ) {
				usort( $authors, function( $a, $b ) {
					$a_name = function_exists( 'mb_strtolower' ) ? mb_strtolower( $a->display_name ) : strtolower( $a->display_name );
					$b_name = function_exists( 'mb_strtolower' ) ? mb_strtolower( $b->display_name ) : strtolower( $b->display_name );
					return strcmp( $a_name, $b_name );
				} );
			}
		}

		return $authors;
	}
}

if ( ! function_exists( 'csco_powerkit_module_enabled' ) ) {
	/**
	 * Helper function to check the status of powerkit modules
	 *
	 * @param array $name Name of module.
	 */
	function csco_powerkit_module_enabled( $name ) {
		if ( function_exists( 'powerkit_module_enabled' ) && powerkit_module_enabled( $name ) ) {
			return true;
		}
	}
}

if ( ! function_exists( 'csco_get_youtube_video_id' ) ) {
	/**
	 * Get Youtube video ID from URL
	 *
	 * @param string $url YouTube URL.
	 */
	function csco_get_youtube_video_id( $url ) {
		preg_match( '/(http(s|):|)\/\/(www\.|)yout(.*?)\/(embed\/|watch.*?v=|)([a-z_A-Z0-9\-]{11})/i', $url, $results );

		if ( isset( $results[6] ) && $results[6] ) {
			return $results[6];
		}
	}
}

if ( ! function_exists( 'csco_get_image_ratio' ) ) {
	/**
	 * Get ratio of image.
	 *
	 * @param string $orientation The name orientation of image.
	 */
	function csco_get_image_ratio( $orientation ) {
		return sprintf( 'cs-ratio-%s', $orientation );
	}
}

if ( ! function_exists( 'csco_get_overlay_type' ) ) {
	/**
	 * Get overlay type.
	 *
	 * @param string $orientation The name orientation of image.
	 */
	function csco_get_overlay_type( $orientation = 'landscape' ) {
		if ( 'original' === $orientation ) {
			return 'cs-overlay-original';
		} else {
			return 'cs-overlay-background';
		}
	}
}

if ( ! function_exists( 'csco_get_image_size_by' ) ) {
	/**
	 * Get image size by image orientation.
	 *
	 * @param string $image_size  The current image size.
	 * @param string $orientation The name orientation of image.
	 */
	function csco_get_image_size_by( $image_size, $orientation = 'landscape' ) {
		if ( 'landscape' === $orientation ) {
			return $image_size;
		}

		if ( 'original' === $orientation ) {
			if ( false !== strpos( $image_size, 'uncropped' ) ) {
				return str_replace( 'uncropped', 'original', $image_size );
			} else {
				return sprintf( '%s-%s', $image_size, $orientation );
			}
		}

		return sprintf( '%s-%s', $image_size, $orientation );
	}
}

if ( ! function_exists( 'csco_add_image_size' ) ) {
	/**
	 * Register a new image size.
	 *
	 * @param string $name    Image size identifier.
	 * @param int    $width   Image width in pixels.
	 * @param int    $height  Image height in pixels.
	 * @param bool   $crop    Whether to crop images to specified width and height or resize.
	 * @param string $mode    Size registration mode.
	 */
	function csco_add_image_size( $name, $width = 0, $height = 0, $crop = false, $mode = null ) {

		$method = get_theme_mod( 'image_sizes_registration_method', 'all' );

		if ( ! $mode ) {

			add_image_size( $name, $width, $height, $crop );

		} elseif ( ( 'auto' === $mode && 'all' === $method ) || true === $mode ) {

			add_image_size( $name, $width, $height, $crop );

			add_image_size( $name . '-original', $width, 0, $crop );

			add_image_size( $name . '-square', $width, $width, $crop );

			add_image_size( $name . '-portrait', $width, $width * 1.25, $crop );

		} elseif ( 'auto' === $mode && 'smart' === $method ) {
			// Get list allow image sizes.
			$orientations = apply_filters( 'csco_allow_image_sizes', array() );

			foreach ( $orientations as $orientation => $sizes ) {
				if ( ! in_array( $orientation, array( 'original', 'landscape', 'square', 'portrait' ), true ) ) {
					continue;
				}

				$sizes = array_unique( $sizes );

				foreach ( $sizes as $size ) {
					if ( $name !== $size ) {
						continue;
					}

					// Change ratio to square.
					if ( 'square' === $orientation ) {
						$name .= '-square';

						$height = $width;
					}

					// Change ratio to portrait.
					if ( 'portrait' === $orientation ) {
						$name .= '-portrait';

						$height = $width * 1.25;
					}

					// Change ratio to original.
					if ( 'original' === $orientation ) {
						$name .= '-original';

						$height = 0;

						$crop = true;
					}

					add_image_size( $name, $width, $height, $crop );
				}
			}
		}
	}
}

if ( ! function_exists( 'csco_get_video_background' ) ) {
	/**
	 * Get element video background
	 *
	 * @param string $location The current location.
	 * @param int    $post_id  The id of post.
	 * @param string $template Template.
	 * @param bool   $tools    Display tools.
	 * @param bool   $link     Display link.
	 */
	function csco_get_video_background( $location = null, $post_id = null, $template = 'default', $tools = true, $link = false ) {
		if ( ! $post_id ) {
			$post_id = get_the_ID();
		}

		$url   = get_post_meta( $post_id, 'csco_post_video_url', true );
		$start = get_post_meta( $post_id, 'csco_post_video_bg_start_time', true );
		$end   = get_post_meta( $post_id, 'csco_post_video_bg_end_time', true );

		if ( $location ) {
			$support = (array) get_post_meta( $post_id, 'csco_post_video_location', true );

			if ( ! in_array( $location, $support, true ) ) {
				return;
			}
		}

		$id = csco_get_youtube_video_id( $url );
		if ( $id ) {
		?>
			<div class="cs-video-wrapper" data-video-id="<?php echo esc_attr( $id ); ?>" data-video-start="<?php echo esc_attr( (int) $start ); ?>" data-video-end="<?php echo esc_attr( (int) $end ); ?>">
				<div class="cs-video-inner"></div>
			</div>
			<?php if ( $tools ) { ?>
				<div class="cs-video-tools cs-video-tools-<?php echo esc_attr( $template ); ?>">
					<?php if ( $link ) { ?>
						<a class="cs-player-control cs-player-link cs-player-stop" target="_blank" href="<?php echo esc_url( $url ); ?>">
							<span class="cs-tooltip"><span><?php esc_html_e( 'View on YouTube', 'once' ); ?></span></span>
						</a>
					<?php } ?>
					<span class="cs-player-control cs-player-volume cs-player-mute"></span>
					<span class="cs-player-control cs-player-state cs-player-pause"></span>
				</div>
			<?php } ?>
		<?php
		}
	}
}

if ( ! function_exists( 'csco_get_archive_location' ) ) {
	/**
	 * Returns Archive Location.
	 */
	function csco_get_archive_location() {

		global $wp_query;

		if ( isset( $wp_query->query_vars['csco_query']['location'] ) ) {

			return $wp_query->query_vars['csco_query']['location'];
		}

		if ( is_home() ) {

			return 'home';

		} else {

			return 'archive';
		}
	}
}

if ( ! function_exists( 'csco_get_archive_option' ) ) {
	/**
	 * Returns Archive Option Name.
	 *
	 * @param string $option_name The customize option name.
	 */
	function csco_get_archive_option( $option_name ) {

		return csco_get_archive_location() . '_' . $option_name;
	}
}

if ( ! function_exists( 'csco_get_page_preview' ) ) {
	/**
	 * Returns Page Preview.
	 */
	function csco_get_page_preview() {

		if ( is_home() ) {

			return apply_filters( 'csco_page_media_preview', get_theme_mod( 'homepage_media_preview', 'cropped' ) );
		}

		if ( is_singular( array( 'post', 'page' ) ) ) {

			$post_type = get_post_type( get_queried_object_id() );

			return apply_filters( 'csco_page_media_preview', get_theme_mod( $post_type . '_media_preview', 'cropped' ) );
		}

		if ( is_archive() ) {

			return apply_filters( 'csco_page_media_preview', get_theme_mod( 'archive_media_preview', 'cropped' ) );
		}

		if ( is_404() ) {

			return apply_filters( 'csco_page_media_preview', 'cropped' );
		}

		return apply_filters( 'csco_page_media_preview', 'cropped' );
	}
}

if ( ! function_exists( 'csco_get_page_sidebar' ) ) {
	/**
	 * Returns Page Sidebar: right, left or disabled.
	 *
	 * @param int    $post_id The ID of post.
	 * @param string $sidebar The sidebar of post.
	 */
	function csco_get_page_sidebar( $post_id = false, $sidebar = false ) {

		$location = apply_filters( 'csco_sidebar', 'sidebar-main' );

		if ( ! is_active_sidebar( $location ) ) {
			return 'disabled';
		}

		$home_id = false;

		if ( 'page' === get_option( 'show_on_front', 'posts' ) ) {

			$page_on_front = get_option( 'page_on_front' );

			if ( $post_id && intval( $post_id ) === intval( $page_on_front ) ) {
				$home_id = $post_id;
			}
		}

		if ( is_home() || $home_id ) {

			$show_on_front = get_option( 'show_on_front', 'posts' );

			if ( 'posts' === $show_on_front ) {

				return apply_filters( 'csco_page_sidebar', get_theme_mod( 'home_sidebar', 'right' ) );
			}

			if ( 'page' === $show_on_front ) {

				$home_id = $home_id ? $home_id : get_queried_object_id();

				// Get sidebar for the blog posts page.
				if ( ! $sidebar ) {
					$sidebar = get_post_meta( $home_id, 'csco_singular_sidebar', true );
				}

				if ( ! $sidebar || 'default' === $sidebar ) {

					return apply_filters( 'csco_page_sidebar', get_theme_mod( 'page_sidebar', 'right' ) );
				}

				return apply_filters( 'csco_page_sidebar', $sidebar );
			}
		}

		if ( is_singular( array( 'post', 'page' ) ) || $post_id ) {

			$post_id = $post_id ? $post_id : get_queried_object_id();

			// Get sidebar for current post.
			if ( ! $sidebar ) {
				$sidebar = get_post_meta( $post_id, 'csco_singular_sidebar', true );
			}

			if ( ! $sidebar || 'default' === $sidebar ) {

				$post_type = get_post_type( $post_id );

				if ( 'page' === $post_type ) {
					return apply_filters( 'csco_page_sidebar', get_theme_mod( $post_type . '_sidebar', 'right' ) );
				} else {
					return apply_filters( 'csco_page_sidebar', get_theme_mod( $post_type . '_sidebar', 'disabled' ) );
				}
			}

			return apply_filters( 'csco_page_sidebar', $sidebar );
		}

		if ( is_archive() ) {

			return apply_filters( 'csco_page_sidebar', get_theme_mod( 'archive_sidebar', 'right' ) );
		}

		if ( is_404() ) {

			return apply_filters( 'csco_page_sidebar', 'disabled' );
		}

		return apply_filters( 'csco_page_sidebar', 'right' );
	}
}

if ( ! function_exists( 'csco_get_page_header_type' ) ) {
	/**
	 * Returns Page Header
	 *
	 * @param int    $post_id The ID of post.
	 * @param string $header  The header of post.
	 */
	function csco_get_page_header_type( $post_id = false, $header = false ) {

		$allow = array( 'none', 'standard', 'small', 'large', 'title' );

		if ( is_singular( array( 'post', 'page' ) ) || $post_id ) {

			$post_id = $post_id ? $post_id : get_queried_object_id();

			// Get header for current post.
			if ( ! $header ) {
				$header = get_post_meta( $post_id, 'csco_page_header_type', true );
			}

			if ( ! in_array( $header, $allow, true ) || 'default' === $header ) {

				$post_type = get_post_type( $post_id );

				return apply_filters( 'csco_page_header_type', get_theme_mod( $post_type . '_header_type', 'standard' ) );
			}

			return apply_filters( 'csco_page_header_type', $header );
		}

		return apply_filters( 'csco_page_header_type', 'standard' );
	}
}

if ( ! function_exists( 'csco_get_state_large_section' ) ) {
	/**
	 * Get the state of large sections.
	 */
	function csco_get_state_large_section() {

		$state = apply_filters( 'csco_state_large_section', null );

		if ( null !== $state ) {
			return $state;
		}

		// Post Featured.
		if ( is_front_page() || is_home() ) {
			$components = get_theme_mod( 'homepage_components', csco_homepage_components_default() );

			if ( ! is_array( $components ) || ! isset( $components[0] ) || 'featured' !== $components[0] ) {
				return;
			}

			$ids = csco_get_featured_ids();

			if ( ! is_array( $ids ) ) {
				return;
			}

			$post_id = array_shift( $ids );

			$type = get_theme_mod( 'featured_layout', 'small' );

			if ( 'default' === $type ) {
				$type = csco_get_page_header_type( $post_id );
			}

			if ( 'large' !== $type || ! has_post_thumbnail( $post_id ) ) {
				return;
			}

			$paged = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;

			if ( 1 !== $paged ) {
				return;
			}

			if ( is_front_page() && 'page' === get_option( 'show_on_front', 'posts' ) && 'home' === get_theme_mod( 'featured_location', 'front_page' ) ) {
				return;
			}

			if ( is_home() && 'page' === get_option( 'show_on_front', 'posts' ) && 'front_page' === get_theme_mod( 'featured_location', 'front_page' ) ) {
				return;
			}

			return true;
		}

		// Page Header.
		if ( is_author() || is_archive() || is_search() || is_404() ) {
			return true;
		}

		// Large Header.
		if ( is_singular() && 'large' === csco_get_page_header_type() && has_post_thumbnail() ) {
			return true;
		}
	}
}

if ( ! function_exists( 'csco_section_class' ) ) {
	/**
	 * Displays the class names for the section element.
	 *
	 * @param string $class      The current classes of section.
	 * @param string $background The background of section.
	 * @param mixed  $scheme     The current background scheme.
	 */
	function csco_section_class( $class = null, $background = '#FFFFFF', $scheme = 'auto' ) {
		global $csco_prev_section_bg;

		$csco_current_section_bg = strtoupper( $background );

		// Background scheme.
		if ( 'auto' === $scheme ) {
			$class .= csco_light_or_dark( $csco_current_section_bg, null, ' cs-bg-dark' );
		}

		// Check prev bg color.
		if ( $csco_prev_section_bg ) {
			$csco_prev_section_bg    = strtoupper( $csco_prev_section_bg );
			$csco_current_section_bg = strtoupper( $csco_current_section_bg );

			// If the background color in the sections is different.
			if ( $csco_prev_section_bg === $csco_current_section_bg ) {
				$class .= ' cs-section-same-color';
			}
		}

		// Check section white.
		if ( '#FFFFFF' === $csco_current_section_bg ) {
			$class .= ' cs-section-white';
		}

		$csco_prev_section_bg = $csco_current_section_bg;

		return $class;
	}
}

if ( ! function_exists( 'csco_get_state_load_nextpost' ) ) {
	/**
	 * State Auto Load Next Post.
	 */
	function csco_get_state_load_nextpost() {

		if ( is_singular( 'post' ) ) {
			$page_load_nextpost = get_post_meta( get_queried_object_id(), 'csco_page_load_nextpost', true );

			if ( ! $page_load_nextpost || 'default' === $page_load_nextpost ) {

				return apply_filters( 'csco_page_load_nextpost', get_theme_mod( 'post_load_nextpost', false ) );
			}

			$page_load_nextpost = 'enabled' === $page_load_nextpost ? true : false;

			return apply_filters( 'csco_page_load_nextpost', $page_load_nextpost );
		}

		return apply_filters( 'csco_page_load_nextpost', false );
	}
}

if ( ! function_exists( 'csco_exclude_duplicate_ids' ) ) {
	/**
	 * Exclude Duplicate Posts
	 *
	 * @param string $function The name search function.
	 * @param array  $ids      Current list ids.
	 */
	function csco_exclude_duplicate_ids( $function, & $ids = array() ) {
		global $wp_query;

		$search = $function( $wp_query, false );

		if ( is_array( $search ) ) {
			$ids = array_merge( $ids, $search );
		}

		return $ids;
	}
}

if ( ! function_exists( 'csco_exclude_duplicate_manager' ) ) {
	/**
	 * Exclude Duplicate Manager
	 *
	 * @param string $index The current component.
	 * @param array  $ids   The current ids.
	 */
	function csco_exclude_duplicate_manager( $index, & $ids = array() ) {
		$components = get_theme_mod( 'homepage_components', csco_homepage_components_default() );

		if ( $components && is_array( $components ) ) {

			// Loop through the components.
			foreach ( $components as $component ) {
				if ( $index === $component ) {
					break;
				}

				if ( 'featured' === $component ) {
					csco_exclude_duplicate_ids( 'csco_exclude_featured_post_from_homepage_query', $ids );
				}
				if ( 'tiles' === $component ) {
					csco_exclude_duplicate_ids( 'csco_exclude_tiles_from_homepage_query', $ids );
				}
				if ( 'carousel' === $component ) {
					csco_exclude_duplicate_ids( 'csco_exclude_carousel_from_homepage_query', $ids );
				}
			}
		}
	}
}

if ( ! function_exists( 'csco_get_count_tiles' ) ) {
	/**
	 * Get count posts of post tiles
	 *
	 * @param string $type The type.
	 */
	function csco_get_count_tiles( $type ) {
		switch ( $type ) {
			case 'type-1':
				return 5;
			case 'type-2':
				return 5;
			case 'type-3':
				return 3;
			case 'type-4':
				return 6;
			case 'type-5':
				return 6;
			default:
				return 5;
		}
	}
}

if ( ! function_exists( 'csco_get_posts_tiles' ) ) {
	/**
	 * Get posts of tiles
	 *
	 * @param array $layouts The layouts.
	 */
	function csco_get_posts_tiles( $layouts = array() ) {
		if ( ! $layouts ) {
			return;
		}

		foreach ( $layouts as $layout ) {
			set_query_var( 'csco_tile_layout', $layout );
			get_template_part( 'template-parts/tile-content' );
		}
	}
}

if ( ! function_exists( 'csco_get_posts_ids' ) ) {
	/**
	 * Get IDs of section posts
	 *
	 * @param string $location       The Location.
	 * @param int    $posts_per_page Number of post to show.
	 * @param array  $post__not_in   Displays all posts except specified.
	 */
	function csco_get_posts_ids( $location = 'featured', $posts_per_page = 'auto', $post__not_in = array() ) {
		global $wp_query;

		$cache_key = md5( maybe_serialize( func_get_args() ) );

		$post_ids = get_query_var( $cache_key );

		if ( ! $post_ids ) {

			// Get numbers posts.
			if ( 'auto' === $posts_per_page ) {
				$posts_per_page = 1;
			}

			// Set arg.
			$args = array(
				'ignore_sticky_posts' => true,
				'order'               => 'DESC',
				'posts_per_page'      => $posts_per_page,
			);

			$categories = get_theme_mod( $location . '_filter_categories' );

			// Filter by categories.
			if ( $categories ) {
				$categories = array_map( 'trim', explode( ',', $categories ) );
				// Category.
				$args['tax_query'] = array(
					array(
						'taxonomy'         => 'category',
						'field'            => 'slug',
						'terms'            => $categories,
						'include_children' => true,
					),
				);
			}

			$tags = get_theme_mod( $location . '_filter_tags' );

			// Filter by tags.
			if ( $tags ) {
				// Tag.
				$args['tag'] = $tags;
			}

			$posts = get_theme_mod( $location . '_filter_posts' );

			// Filter by posts.
			if ( $posts ) {
				$args['post_type'] = array( 'post', 'page' );

				$args['post__in'] = explode( ',', str_replace( ' ', '', $posts ) );
			} else {
				// Exclude singular ID.
				if ( is_singular() ) {
					array_push( $post__not_in, get_the_ID() );
				}

				$args['post__not_in'] = $post__not_in;
			}

			$orderby = get_theme_mod( $location . '_orderby', 'date' );

			// Post order.
			if ( 'post_views' === $orderby && class_exists( 'Post_Views_Counter' ) ) {
				// Post Views.
				$args['orderby'] = 'post_views';
				// Don't hide posts without views.
				$args['views_query']['hide_empty'] = false;
				// Time Frame for Post Views.
				$time_frame = get_theme_mod( $location . '_time_frame' );
				if ( $time_frame ) {
					$args['date_query'] = array(
						array(
							'column' => 'post_date_gmt',
							'after'  => $time_frame . ' ago',
						),
					);
				}
			} else {
				// Date.
				$args['orderby'] = 'date';
			}

			$args = apply_filters( 'csco_' . $location . '_args', $args );

			$post_ids = array();

			$the_query = new WP_Query( $args );
			if ( $the_query->have_posts() ) {
				while ( $the_query->have_posts() ) {
					$the_query->the_post();
					$post_ids[] = get_the_ID();
				}
				wp_reset_postdata();
			}

			set_query_var( $cache_key, $post_ids );
		}

		return apply_filters( 'csco_' . $location . '_ids', $post_ids );
	}
}

/**
 * -------------------------------------
 * Get IDs of posts
 * -------------------------------------
 */

if ( ! function_exists( 'csco_get_featured_ids' ) ) {
	/**
	 * Get IDs of featured post
	 */
	function csco_get_featured_ids() {
		$post__not_in = array();

		if ( get_theme_mod( 'featured_avoid_duplicate' ) ) {
			csco_exclude_duplicate_manager( 'featured', $post__not_in );
		}

		$ids = csco_get_posts_ids( 'featured', 1, $post__not_in );

		if ( count( $ids ) >= 1 ) {
			return $ids;
		}
	}
}

if ( ! function_exists( 'csco_get_tiles_ids' ) ) {
	/**
	 * Get IDs of Post Tiles
	 */
	function csco_get_tiles_ids() {
		$post__not_in = array();

		if ( get_theme_mod( 'tiles_avoid_duplicate' ) ) {
			csco_exclude_duplicate_manager( 'tiles', $post__not_in );
		}

		$posts_per_page = csco_get_count_tiles( get_theme_mod( 'tiles_type', 'type-1' ) );

		$ids = csco_get_posts_ids( 'tiles', $posts_per_page, $post__not_in );

		if ( count( $ids ) >= $posts_per_page ) {
			return $ids;
		}
	}
}

if ( ! function_exists( 'csco_get_carousel_ids' ) ) {
	/**
	 * Get IDs of Post Carousel
	 */
	function csco_get_carousel_ids() {
		$post__not_in = array();

		if ( get_theme_mod( 'carousel_avoid_duplicate' ) ) {
			csco_exclude_duplicate_manager( 'carousel', $post__not_in );
		}

		$posts_per_page = get_theme_mod( 'carousel_number_slides', 5 );

		$ids = csco_get_posts_ids( 'carousel', $posts_per_page, $post__not_in );

		if ( count( $ids ) >= $posts_per_page ) {
			return $ids;
		}
	}
}
